@@ -16,7 +16,7 @@ use namespace::autoclean;
 extends 'App::Sqitch::Command';
 with 'App::Sqitch::Role::RevertDeployCommand';
 
-our $VERSION = '0.999';
+our $VERSION = '0.9991';
 
 has client => (
     is       => 'ro',
@@ -33,28 +33,19 @@ sub configure { {} }
 
 sub execute {
     my $self = shift;
-    my %args = $self->parse_args(target => $self->target, args => \@_);
-
-    # The branch arg will be the one parse_args does not recognize.
-    my $branch = shift @{ $args{unknown} } // $self->usage;
-
-    # Die on unknowns.
-    if (my @unknown = ( @{ $args{unknown} }, @{ $args{changes} } ) ) {
-        hurl checkout => __nx(
-            'Unknown argument "{arg}"',
-            'Unknown arguments: {arg}',
-            scalar @unknown,
-            arg => join ', ', @unknown
-        );
-    }
+    my ($branch, $targets) = $self->parse_args(
+        target     => $self->target,
+        names      => [undef],
+        args       => \@_,
+        no_changes => 1,
+    );
 
     # Warn on multiple targets.
-    my $target = shift @{ $args{targets} };
+    my $target = shift @{ $targets };
     $self->warn(__x(
         'Too many targets specified; connecting to {target}',
         target => $target->name,
-    )) if @{ $args{targets} };
-
+    )) if @{ $targets };
 
     # Now get to work.
     my $sqitch = $self->sqitch;
@@ -195,7 +186,7 @@ The Sqitch command-line client.
 
 =head1 License
 
-Copyright (c) 2012-2014 Ronan Dunklau & iovation Inc.
+Copyright (c) 2012-2015 Ronan Dunklau & iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
