@@ -13,7 +13,7 @@ use Try::Tiny;
 use namespace::autoclean;
 extends 'App::Sqitch::Command';
 
-our $VERSION = '0.999';
+our $VERSION = '0.9991';
 
 has target_name => (
     is  => 'ro',
@@ -168,6 +168,13 @@ sub configure {
         App::Sqitch::DateTime->validate_as_string_format($format);
     }
 
+    # Set boolean options from config.
+    for my $key (qw(show_changes show_tags)) {
+        next if exists $opt->{$key};
+        my $val = $config->get(key => "status.$key", as => 'bool') // next;
+        $opt->{$key} = $val;
+    }
+
     my $ret = $class->SUPER::configure( $config, $opt );
     $ret->{target_name} = delete $ret->{target} if exists $ret->{target};
     return $ret;
@@ -398,7 +405,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2014 iovation Inc.
+Copyright (c) 2012-2015 iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
