@@ -5,13 +5,30 @@ use strict;
 use warnings;
 use utf8;
 use Moo;
-use Types::Standard qw(Str ArrayRef);
+use App::Sqitch::X qw(hurl);
+use Types::Standard qw(Str ArrayRef Maybe Bool);
 use Locale::TextDomain qw(App-Sqitch);
 use namespace::autoclean;
 
 extends 'App::Sqitch::Command';
 
-our $VERSION = '0.999';
+our $VERSION = '0.9991';
+
+has tag_name => (
+    is  => 'ro',
+    isa => Maybe[Str],
+);
+
+has change_name => (
+    is  => 'ro',
+    isa => Maybe[Str],
+);
+
+has all => (
+    is      => 'ro',
+    isa     => Bool,
+    default => 0
+);
 
 has note => (
     is       => 'ro',
@@ -21,35 +38,68 @@ has note => (
 
 sub options {
     return qw(
+        tag-name|tag|t=s
+        change-name|change|c=s
+        all|a!
         note|n|m=s@
     );
 }
 
+sub configure {
+    my ( $class, $config, $opt ) = @_;
+    # Just keep options.
+    return $opt;
+}
+
 sub execute {
-    my ( $self, $name, $change ) = @_;
-    my $target = $self->default_target;
-    my $plan   = $target->plan;
+    my $self   = shift;
+    my ($name, $change, $targets) = $self->parse_args(
+        names      => [$self->tag_name, $self->change_name],
+        all        => $self->all,
+        args       => \@_,
+        no_default => 1,
+        no_changes => 1,
+    );
 
     if (defined $name) {
-        my $tag = $plan->tag(
-            name   => $name,
-            change => $change,
-            note   => join "\n\n" => @{ $self->note },
-        );
+        my $note = join "\n\n" => @{ $self->note };
+        my (%seen, @plans, @tags);
+        for my $target (@{ $targets }) {
+            next if $seen{$target->plan_file}++;
+            my $plan = $target->plan;
+            push @tags => $plan->tag(
+                name   => $name,
+                change => $change,
+                note   => $note,
+            );
+            push @plans => $plan;
+        }
 
         # Make sure we have a note.
-        $tag->request_note( for => __ 'tag');
+        $note = $tags[0]->request_note(for => __ 'tag');
 
-        # We good, write the plan file back out.
-        $plan->write_to( $target->plan_file );
-        $self->info(__x(
-            'Tagged "{change}" with {tag}',
-            change => $tag->change->format_name,
-            tag    => $tag->format_name,
-        ));
+        # We good, write the plan files back out.
+        for my $plan (@plans) {
+            my $tag = shift @tags;
+            $tag->note($note);
+            $plan->write_to( $plan->file );
+            $self->info(__x(
+                'Tagged "{change}" with {tag} in {file}',
+                change => $tag->change->format_name,
+                tag    => $tag->format_name,
+                file   => $plan->file,
+            ));
+        }
     } else {
-        # Emit a list of tags.
-        $self->info($_->format_name) for $plan->tags;
+        # Show unique tags.
+        my %seen;
+        for my $target (@{ $targets }) {
+            my $plan = $target->plan;
+            for my $tag ($plan->tags) {
+                my $name = $tag->format_name;
+                $self->info($name) unless $seen{$name}++;
+            }
+        }
     }
 
     return $self;
@@ -61,7 +111,7 @@ __END__
 
 =head1 Name
 
-App::Sqitch::Command::tag - Add or list tags in a Sqitch plan
+App::Sqitch::Command::tag - Add or list tags in Sqitch plans
 
 =head1 Synopsis
 
@@ -76,6 +126,19 @@ Tags a Sqitch change. The tag will be added to the last change in the plan.
 
 =head2 Attributes
 
+=head3 C<tag_name>
+
+The name of the tag to add.
+
+=head3 C<change_name>
+
+The name of the change to tag.
+
+=head3 C<all>
+
+Boolean indicating whether or not to run the command against all plans in the
+project.
+
 =head3 C<note>
 
 Text of the tag note.
@@ -108,7 +171,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2014 iovation Inc.
+Copyright (c) 2012-2015 iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
