@@ -12,7 +12,7 @@ use List::Util qw(first);
 use namespace::autoclean;
 extends 'App::Sqitch::Command';
 
-our $VERSION = '0.999';
+our $VERSION = '0.9991';
 
 has target => (
     is  => 'ro',
@@ -83,33 +83,26 @@ sub configure {
 
 sub execute {
     my $self = shift;
-    my %args = $self->parse_args(target => $self->target, args => \@_);
-
-    # Die on unknowns.
-    if (my @unknown = @{ $args{unknown}} ) {
-        hurl verify => __nx(
-            'Unknown argument "{arg}"',
-            'Unknown arguments: {arg}',
-            scalar @unknown,
-            arg => join ', ', @unknown
-        );
-    }
+    my ($targets, $changes) = $self->parse_args(
+        target => $self->target,
+        args   => \@_,
+    );
 
     # Warn on multiple targets.
-    my $target = shift @{ $args{targets} };
+    my $target = shift @{ $targets };
     $self->warn(__x(
         'Too many targets specified; connecting to {target}',
         target => $target->name,
-    )) if @{ $args{targets} };
+    )) if @{ $targets };
 
     # Warn on too many changes.
-    my $from = $self->from_change // shift @{ $args{changes} };
-    my $to   = $self->to_change   // shift @{ $args{changes} };
+    my $from = $self->from_change // shift @{ $changes };
+    my $to   = $self->to_change   // shift @{ $changes };
     $self->warn(__x(
         'Too many changes specified; verifying from "{from}" to "{to}"',
         from => $from,
         to   => $to,
-    )) if @{ $args{changes} };
+    )) if @{ $changes };
 
     # Now get to work.
     my $engine = $target->engine;
@@ -194,7 +187,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2014 iovation Inc.
+Copyright (c) 2012-2015 iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
