@@ -10,13 +10,13 @@ use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::Plan::Change;
 use Path::Class;
 use Moo;
-use App::Sqitch::Types qw(DBH URIDB ArrayRef);
+use App::Sqitch::Types qw(DBH URIDB ArrayRef Bool Str);
 use namespace::autoclean;
 use List::MoreUtils qw(firstidx);
 
 extends 'App::Sqitch::Engine';
 
-our $VERSION = '0.999';
+our $VERSION = '0.9991';
 
 has registry_uri => (
     is       => 'ro',
@@ -75,7 +75,7 @@ has dbh => (
                     $dbh->do("SET SESSION $_") for (
                         q{character_set_client   = 'utf8'},
                         q{character_set_server   = 'utf8'},
-                        q{default_storage_engine = 'InnoDB'},
+                        ($dbh->{mysql_serverversion} < 50500 ? () : (q{default_storage_engine = 'InnoDB'})),
                         q{time_zone              = '+00:00'},
                         q{group_concat_max_len   = 32768},
                         q{sql_mode = '} . join(',', qw(
@@ -96,7 +96,7 @@ has dbh => (
         # Make sure we support this version.
         my ($dbms, $vnum, $vstr) = $dbh->{mysql_serverinfo} =~ /mariadb/i
             ? ('MariaDB', 50300, '5.3')
-            : ('MySQL',   50604, '5.6.4');
+            : ('MySQL',   50100, '5.1.0');
         hurl mysql => __x(
             'Sqitch requires {rdbms} {want_version} or higher; this is {have_version}',
             rdbms        => $dbms,
@@ -108,7 +108,17 @@ has dbh => (
     }
 );
 
-# Need to wait until dbh is defined.
+has _ts_default => (
+    is      => 'ro',
+    isa     => Str,
+    lazy    => 1,
+    default => sub {
+        return 'utc_timestamp(6)' if shift->_fractional_seconds;
+        return 'utc_timestamp';
+    },
+);
+
+# Need to wait until dbh and _ts_default are defined.
 with 'App::Sqitch::Role::DBIEngine';
 
 has _mysql => (
@@ -144,7 +154,7 @@ has _mysql => (
         # }
 
         push @ret => (
-            '--skip-pager',
+            ($^O eq 'MSWin32' ? () : '--skip-pager' ),
             '--silent',
             '--skip-column-names',
             '--skip-line-numbers',
@@ -153,6 +163,18 @@ has _mysql => (
     },
 );
 
+has _fractional_seconds => (
+    is      => 'ro',
+    isa     => Bool,
+    lazy    => 1,
+    default => sub {
+        my $dbh = shift->dbh;
+        return $dbh->{mysql_serverinfo} !~ /mariadb/i
+            && $dbh->{mysql_serverversion} >= 50604;
+    },
+);
+
+
 sub mysql { @{ shift->_mysql } }
 
 sub key    { 'mysql' }
@@ -168,8 +190,6 @@ sub _ts2char_format {
     return q{date_format(%s, 'year:%%Y:month:%%m:day:%%d:hour:%%H:minute:%%i:second:%%S:time_zone:UTC')};
 }
 
-sub _ts_default { 'utc_timestamp(6)' }
-
 sub _quote_idents {
     shift;
     map { $_ eq 'change' ? '"change"' : $_ } @_;
@@ -258,6 +278,28 @@ sub _listagg_format {
     return q{group_concat(%s SEPARATOR ' ')};
 }
 
+sub _prepare_to_log {
+    my ($self, $table, $change) = @_;
+    return $self if $self->_fractional_seconds;
+
+    # No sub-second precision, so delay logging a change until a second has passed.
+    my $dbh = $self->dbh;
+    my $sth = $dbh->prepare(qq{
+        SELECT UNIX_TIMESTAMP(committed_at) >= UNIX_TIMESTAMP()
+          FROM $table
+         WHERE project = ?
+         ORDER BY committed_at DESC
+         LIMIT 1
+    });
+    while ($dbh->selectcol_arrayref($sth, undef, $change->project)->[0]) {
+        # Sleep for 100 ms.
+        require Time::HiRes;
+        Time::HiRes::sleep(0.1);
+    }
+
+    return $self;
+}
+
 sub _run {
     my $self = shift;
     my $sqitch = $self->sqitch;
@@ -297,9 +339,24 @@ sub run_verify {
 
 sub run_upgrade {
     my ($self, $file) = @_;
+    my $dbh = $self->dbh;
     my @cmd = $self->mysql;
     $cmd[1 + firstidx { $_ eq '--database' } @cmd ] = $self->registry;
-    $self->sqitch->run( @cmd, '--execute', "source $file" );
+    return $self->sqitch->run( @cmd, '--execute', "source $file" )
+        if $self->_fractional_seconds;
+
+    # Need to strip out datetime precision.
+    (my $sql = scalar $file->slurp) =~ s{DATETIME\(\d+\)}{DATETIME}g;
+
+    # Strip out 5.5 stuff on earlier versions.
+    $sql =~ s/-- ## BEGIN 5[.]5.+?-- ## END 5[.]5//ms if $dbh->{mysql_serverversion} < 50500;
+
+    # Write out a temp file and execute it.
+    require File::Temp;
+    my $fh = File::Temp->new;
+    print $fh $sql;
+    close $fh;
+    $self->sqitch->run( @cmd, '--execute', "source $fh" );
 }
 
 sub run_handle {
@@ -344,7 +401,8 @@ App::Sqitch::Engine::mysql - Sqitch MySQL Engine
 =head1 Description
 
 App::Sqitch::Engine::mysql provides the MySQL storage engine for Sqitch. It
-supports MySQL 5.6.4 and higher, as well as MariaDB 5.3.0 and higher.
+supports MySQL 5.1.0 and higher (best on 5.6.4 and higher), as well as MariaDB
+5.3.0 and higher.
 
 =head1 Interface
 
@@ -361,7 +419,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2014 iovation Inc.
+Copyright (c) 2012-2015 iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
