@@ -15,7 +15,7 @@ use namespace::autoclean;
 
 extends 'App::Sqitch::Engine';
 
-our $VERSION = '0.999';
+our $VERSION = '0.9991';
 
 sub destination {
     my $self = shift;
@@ -162,11 +162,17 @@ sub initialized {
 
 sub initialize {
     my $self   = shift;
-    my $schema = $self->registry;
     hurl engine => __x(
         'Sqitch schema "{schema}" already exists',
-        schema => $schema
+        schema => $self->registry
     ) if $self->initialized;
+    $self->_run_registry_file( file(__FILE__)->dir->file('pg.sql') );
+    $self->_register_release;
+}
+
+sub _run_registry_file {
+    my ($self, $file) = @_;
+    my $schema = $self->registry;
 
     # Check the client version.
     my ($maj, $min);
@@ -187,8 +193,6 @@ sub initialize {
            AND proname = 'pgxc_version';
     });
 
-    my $file = file(__FILE__)->dir->file('pg.sql');
-
     if ($maj < 9) {
         # Need to write a temp file; no :"registry" variable syntax.
         ($schema) = $self->dbh->selectrow_array(
@@ -213,7 +217,6 @@ sub initialize {
     }
 
     $self->dbh->do('SET search_path = ?', undef, $schema);
-    $self->_register_release;
 }
 
 # Override to lock the changes table. This ensures that only one instance of
@@ -245,6 +248,10 @@ sub run_handle {
     $self->_spool($fh);
 }
 
+sub run_upgrade {
+    shift->_run_registry_file(@_);
+}
+
 # Override to avoid cast errors, and to use VALUES instead of a UNION query.
 sub log_new_tags {
     my ( $self, $change ) = @_;
@@ -545,7 +552,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2014 iovation Inc.
+Copyright (c) 2012-2015 iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
