@@ -15,7 +15,7 @@ use namespace::autoclean;
 
 extends 'App::Sqitch::Engine';
 
-our $VERSION = '0.999';
+our $VERSION = '0.9991';
 
 has registry_uri => (
     is       => 'ro',
@@ -228,6 +228,13 @@ sub run_handle {
     $self->_spool($fh);
 }
 
+sub run_upgrade {
+    my ($self, $file) = @_;
+    my @cmd = $self->sqlite3;
+    $cmd[-1] = $self->registry_uri->dbname;
+    return $self->sqitch->run( @cmd, $self->_read($file) );
+}
+
 sub _read {
     my $self = shift;
     my $cmd = '.read ' . $self->dbh->quote(shift);
@@ -237,8 +244,6 @@ sub _read {
 
 1;
 
-1;
-
 __END__
 
 =head1 Name
@@ -277,7 +282,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2014 iovation Inc.
+Copyright (c) 2012-2015 iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
