@@ -18,7 +18,7 @@ use Moo;
 use App::Sqitch::Types qw(Str Int HashRef ChangeList LineList Maybe Sqitch URI File Target);
 use constant SYNTAX_VERSION => '1.0.0';
 
-our $VERSION = '0.999';
+our $VERSION = '0.9991';
 
 # Like [:punct:], but excluding _. Copied from perlrecharclass.
 my $punct = q{-!"#$%&'()*+,./:;<=>?@[\\]^`{|}~};
@@ -189,7 +189,7 @@ sub _parse {
 
     # First, find pragmas.
     HEADER: while ( my $line = $fh->getline ) {
-        chomp $line;
+        $line =~ s/\r?\n\z//;
 
         # Grab blank lines first.
         if ($line =~ /\A(?<lspace>[[:blank:]]*)(?:#[[:blank:]]*(?<note>.+)|$)/) {
@@ -266,7 +266,7 @@ sub _parse {
     ) unless $pragmas{project};
 
     LINE: while ( my $line = $fh->getline ) {
-        chomp $line;
+        $line =~ s/\r?\n\z//;
 
         # Grab blank lines first.
         if ($line =~ /\A(?<lspace>[[:blank:]]*)(?:#[[:blank:]]*(?<note>.+)|$)/) {
@@ -748,7 +748,6 @@ sub tag {
         plan   => $self,
         name   => $name,
         change => $change,
-        rspace => $p{note} ? ' ' : '',
     );
 
     $change->add_tag($tag);
@@ -796,15 +795,14 @@ sub add {
     if ( defined( my $idx = $changes->index_of( $p{name} . '@HEAD' ) ) ) {
         my $tag_idx = $changes->index_of_last_tagged;
         hurl plan => __x(
-            qq{Change "{change}" already exists.\n}
+            qq{Change "{change}" already exists in plan {file}.\n}
             . 'Use "sqitch rework" to copy and rework it',
             change => $p{name},
+            file   => $self->file,
         );
     }
 
     $self->_parse_deps(\%p);
-
-    $p{rspace} //= ' ' if $p{note};
     my $change = App::Sqitch::Plan::Change->new( %p, plan => $self );
 
     # Make sure dependencies are valid.
@@ -830,9 +828,10 @@ sub rework {
     my ( $self, %p ) = @_;
     my $changes = $self->_changes;
     my $idx   = $changes->index_of( $p{name} . '@HEAD') // hurl plan => __x(
-        qq{Change "{change}" does not exist.\n}
+        qq{Change "{change}" does not exist in {file}.\n}
         . 'Use "sqitch add {change}" to add it to the plan',
         change => $p{name},
+        file   => $self->file,
     );
 
     my $tag_idx = $changes->index_of_last_tagged;
@@ -1596,7 +1595,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2014 iovation Inc.
+Copyright (c) 2012-2015 iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
