@@ -8,7 +8,7 @@ use App::Sqitch::Types qw(Str Plan);
 use App::Sqitch::X qw(hurl);
 use Locale::TextDomain qw(App-Sqitch);
 
-our $VERSION = '0.999';
+our $VERSION = '0.9991';
 
 has name => (
     is       => 'ro',
@@ -29,7 +29,7 @@ has lspace => (
 );
 
 has rspace => (
-    is       => 'ro',
+    is       => 'rwp',
     isa      => Str,
     default  => '',
 );
@@ -52,6 +52,11 @@ has note => (
     default  => '',
 );
 
+after note => sub {
+    my $self = shift;
+    $self->_set_rspace(' ') if $_[0] && !$self->rspace;
+};
+
 has plan => (
     is       => 'ro',
     isa      => Plan,
@@ -77,6 +82,7 @@ sub BUILDARGS {
         $note =~ s/\s+\z//;
         $note =~ s/(\\[\\nr])/$unescape{$1}/g;
         $p->{note} = $note;
+        $p->{rspace} //= ' ' if $note && $p->{name};
     }
     return $p;
 }
@@ -114,7 +120,7 @@ sub request_note {
     $note =~ s/\A\v+//;
     $note =~ s/\v+\z//;
 
-    # Set the note via the meta API, bypassing the read-only constraint.
+    # Set the note.
     $self->note($note);
     return $note;
 }
@@ -341,7 +347,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2014 iovation Inc.
+Copyright (c) 2012-2015 iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
