@@ -11,7 +11,7 @@ use App::Sqitch::X qw(hurl);
 use Locale::TextDomain qw(App-Sqitch);
 use namespace::autoclean;
 
-our $VERSION = '0.999';
+our $VERSION = '0.9991';
 
 requires 'dbh';
 requires 'sqitch';
@@ -435,6 +435,8 @@ sub _tag_subselect_columns {
     );
 }
 
+sub _prepare_to_log { $_[0] }
+
 sub log_deploy_change {
     my ($self, $change) = @_;
     my $dbh    = $self->dbh;
@@ -462,6 +464,8 @@ sub log_deploy_change {
         planner_email
         committed_at
     ));
+
+    $self->_prepare_to_log(changes => $change);
     $dbh->do(qq{
         INSERT INTO changes (
             $cols
@@ -559,6 +563,7 @@ sub _log_event {
         committed_at
     ));
 
+    $self->_prepare_to_log(events => $change);
     $dbh->do(qq{
         INSERT INTO events (
             $cols
@@ -857,7 +862,7 @@ sub change_id_for {
     my $project = $p{project} || $self->plan->project;
     if ( my $change = $p{change} ) {
         if ( my $tag = $p{tag} ) {
-            # Ther is nothing before the first tag.
+            # There is nothing before the first tag.
             return undef if $tag eq 'ROOT' || $tag eq 'FIRST';
 
             # Find closest to the end for @HEAD.
@@ -865,7 +870,8 @@ sub change_id_for {
                 if $tag eq 'HEAD' || $tag eq 'LAST';
 
             # Find by change name and following tag.
-            return $dbh->selectcol_arrayref(q{
+            my $limit = $self->_can_limit ? "\n                 LIMIT 1" : '';
+            return $dbh->selectcol_arrayref(qq{
                 SELECT changes.change_id
                   FROM changes
                   JOIN tags
@@ -874,6 +880,7 @@ sub change_id_for {
                  WHERE changes.project = ?
                    AND changes.change  = ?
                    AND tags.tag        = ?
+                 ORDER BY changes.committed_at DESC$limit
             }, undef, $project, $change, '@' . $tag)->[0];
         }
 
@@ -1057,7 +1064,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2014 iovation Inc.
+Copyright (c) 2012-2015 iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
